# Tamarix Analytics

A Python package for row matching and F1 score calculations using the Hungarian algorithm.

## Installation

```bash
pip install tamarix_analytics
```

## Usage

```python
from my_package import match_rows, f1_score_unordered, f1_score_ordered, get_row_score
```